<?php

require('ymldlib.php');

function YMLD_insertOne($conn) {
  $sql = "INSERT INTO PRODUCTIONS (Production_Title,
    Production_StartDate, Production_EndDate)
    VALUES ('Lily of the Valley', '2005-01-18', '2005-02-13')";
  $conn->exec($sql);
}

function YMLD_insertMany($conn) {
  $sql = "INSERT INTO PRODUCTIONS (Production_Title,
    Production_StartDate, Production_EndDate)
    VALUES (?, ?, ?)";
  $stmt = $conn->prepare($sql);

  $productions = array(
    array('Cats and Dogs', '2005-04-01', '2005-05-01'),
    array('Desperate Houses', '2005-05-02', '2005-06-01'),
    array('Icing the Puck', '2005-06-02', '2005-07-01'),
    array('Heroes', '2005-07-02', '2005-08-01'),
    array('Rubber Sacks', '2005-08-02', '2005-09-01'),
    array('Couched in Leather', '2005-09-02', '2005-10-01'),
    array('Backsplash', '2005-10-02', '2005-11-01'),
  );

  foreach ($productions as $row) {
    $stmt->execute($row);
  }

  $stmt = NULL;
}

function YMLD_selectNextShow($conn) {
  $sql = 'SELECT Production_No, Production_Title,
    Production_StartDate, Production_EndDate
    FROM Productions
    WHERE Production_StartDate > CURRENT_DATE
    ORDER BY Production_StartDate';

  $stmt = $conn->query($sql);
  $row = $stmt->fetch();
  $stmt = NULL;
  return $row;
}

function YMLD_callProcedureDoubleIn($conn) {
  $sql = 'CALL double_in(?, ?)';

  $stmt = $conn->prepare($sql);
  $stmt->execute(array('Cats and Dogs', 'My New Title'));
  $stmt = NULL;
}

function YMLD_callProcedureSingleResult($conn) {
  $sql = 'CALL SINGLE_RESULT()';
  $rows = array();

  $stmt = $conn->query($sql);
  while ($row = $stmt->fetch(PDO_FETCH_NUM)) {
    $rows[] = $row;
  }

  $stmt = NULL;
  return $rows;
}

function YMLD_callProcedureInout($conn) {
  $sql = 'CALL production_lists2(:date)';

  $value = '2029-02-04';
  $stmt = $conn->prepare($sql);

  // Bind the INOUT parameter
  $stmt->bindParam(':date', $value,
    PDO_PARAM_STR|PDO_PARAM_INPUT_OUTPUT, 14);
  $stmt->execute();

  $stmt = NULL;
  return $value;
}

function YMLD_callProcedureResults($conn) {
  $sql = 'CALL PRODUCTION_LISTS()';
  $stmt = $conn->query($sql);
  $rows = $stmt->fetchAll(PDO_FETCH_NUM);
  do {
    YMLD_printResults($rows);
    $rows = $stmt->fetchAll(PDO_FETCH_NUM);
  } while ($rows && $stmt->nextRowset());

  $stmt = NULL;
}

function YMLD_printResults($rows) {
  print "\nNew result set:\n";
  foreach ($rows as $row) {
    foreach ($row as $col) {
      print "$col ";
    }
    print "\n";
  }
}

function YMLD_insertSeatImage($conn, $seat_number, $image) {
  $sql = 'INSERT INTO SeatMap (Seat_No, Seat_View) VALUES (?, ?)';

  $fh = fopen($image, 'r');
  $stmt = $conn->prepare($sql);
  $stmt->bindParam(1, $seat_number, PDO_PARAM_INT);
  $stmt->bindParam(2, $fh, PDO_PARAM_LOB);
  $rc = $stmt->execute();
  return $rc;
}

function YMLD_retrieveSeatImages($conn) {
  $seat_sql = 'SELECT Seat_No FROM SeatMap';
  $map_sql = 'SELECT Seat_View FROM SeatMap WHERE SeatNo = ?';

  $seat_stmt = $conn->query($seat_sql);
  $map_stmt = $conn->prepare($map_sql);
  foreach ($seat_stmt->fetchCol() as $seat) {
    $fh = fopen("$seat.gif", 'w');
    $map_stmt->execute(array($seat));
    $map_stmt->bindColumn(1, $fh, PDO_PARAM_LOB);
    $map_stmt->fetch(PDO_FETCH_BOUND);
  }

}

function YMLD_dropTables($conn) {
  $sql = 'DROP TABLE ';
  $tables = array('TRANSACTIONLOG', 'SEATS', 'SEATMAP',
            'PRICEPLAN', 'PERFORMANCES', 'PRODUCTIONS');

  // Begin a new transaction, turning off autocommit
  $conn->beginTransaction();
  foreach ($tables as $table) {
    try {
      $conn->exec("$sql $table");
    }
    catch (PDOException $e) {
      print "Failed to drop table $table\n";
    }
  }

  // We always want to commit this transaction
  if (TRUE) {
    $conn->commit();
    print "Committed!\n";
  }
  else {
    $conn->rollBack();
  }
}

function YMLD_setAutocommit($conn) {
  // Turn autocommit off
  $conn->setAttribute(PDO_ATTR_AUTOCOMMIT, TRUE);
  print checkAutocommit($conn);

  // Turn autocommit on
  $conn->setAttribute(PDO_ATTR_AUTOCOMMIT, TRUE);
  print checkAutocommit($conn);
}

function YMLD_checkAutocommit($conn) {
  if ($conn->getAttribute(PDO_ATTR_AUTOCOMMIT)) {
    return "Autocommit is ON";
  }
  else {
    return "Autocommit is OFF";
  }
}

$conn = YMLD_databaseConnect();
YMLD_insertOne($conn);
YMLD_insertMany($conn);
var_dump(YMLD_selectNextShow($conn));
var_dump(YMLD_callProcedureSingleResult($conn));
print YMLD_callProcedureInout($conn);
YMLD_callProcedureResults($conn);
//YMLD_dropTables($conn);
YMLD_setAutocommit($conn);

?>
