<?php
function YMLD_databaseConnect() {
  $database = 'YMLD';
  $user = 'userid';
  $password = 'password';

  try {
    $conn = new PDO("odbc:$database", $user, $password);
    $conn->exec("SET CURRENT SCHEMA APP");
  }
  catch (PDOException $e) {
    print $e;
  }
  return $conn;
}

function YMLD_select_all_shows($conn) {
  /*   Select the next show from the Productions table, based on
  today's date. If there are no future shows starting after
  today, return None. */

  $sql = "
  SELECT Production_No, Production_Title,
    Production_Start, Production_End
    FROM Productions
    ORDER BY Production_Start
  ";

  $stmt = $conn->prepare($sql);
  $stmt->execute();
  $rows = $stmt->fetchAll(PDO_FETCH_NUM);

  $stmt = NULL;
  return $rows;
}

function YMLD_display_productions($productions) {
  $form = <<<HTML
<table>
  <tr><th>Title</th><th>Start date</th><th>End date</th></tr>
HTML;

  $self = strip_tags(htmlentities($_SERVER['PHP_SELF']));
  foreach ($productions as $show) {
    $form .= "<tr><td><a href='{$self}" .
      "?page=show&id={$show[0]}'>{$show[1]}</a></td>
      <td>{$show[2]}</td><td>{$show[3]}</td></tr>\n";
  }
  $form .= "</table>";
  return $form;
}

function YMLD_display_performances($performances, $seats) {
  /*
  Display performances for a given production with radio buttons
  so a user can display the seats that are available for a given
  performance.
  */

  $self = strip_tags(htmlentities($_SERVER['PHP_SELF']));
  $form = <<<HTML
<table>
  <tr><th>Title</th><th>Date</th><th>Time</th><th>Seats</th></tr>
HTML;
  foreach ($performances as $show) {
    $form .= "<tr><td>{$show[0]}</td><td>{$show[1]}</td>";
    $form .= "<td>{$show[2]}</td><td><$form ";
    $form .= "action='{$self}?page=view' method='POST'>";
    $form .= "<select name='seat'>";
    foreach ($seats[$show[3]] as $seat) {
      $form .= "<option value='{$seat[0]}'>";
      $form .= "{$seat[1]}</option>\n";
    }
    $form .= "</select><input type='submit' value='Display' />";
    $form .= "</$form></td></tr>\n";
  }
  $form .= "</table>";
  return $form;
}

function YMLD_select_performance_data($conn, $production) {
  /* Return an array of all performances for a given production
  that still have seats available. */

  $sql = '
    SELECT Performance_No, Production_Title,
    Performance_Date, Performance_Time
    FROM Productions INNER JOIN Performances
    ON Productions.Production_No = Performances.Production_No
    WHERE Productions.Production_No = ?
    AND Performance_Seats > 1
  ';

  $stmt = $conn->prepare($sql);
  $stmt->execute(array($production));
  $performances = $stmt->fetchAll(PDO_FETCH_NUM);
  $stmt = NULL;
  return $performances;
}

function YMLD_select_available_seats($conn, $performances) {
  /* Return an array of all available seats and prices for a
  given performance of a show. */

  $sql = '
    SELECT Seat_No, PricePlan_Cost
    FROM Seats INNER JOIN PricePlan
    ON Seats.PricePlan_No = PricePlan.PricePlan_No
    WHERE Performance_No = 20
    AND Seat_Available = 1
  ';

  $stmt = $conn->prepare($sql);

  $seats = array();
  foreach ($performances as $show) {
    $show_num = intval($show[0]);
    $stmt->execute(array($show_num));
    $row = $stmt->fetch(PDO_FETCH_NUM);
    while ($row) {
      $seats[$show_num] = array($row[0], $row[1]);
      $row = $stmt->fetch(PDO_FETCH_NUM);
    }
  }

  $stmt = NULL;
  return $seats;
}

?>
